/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : Sept. 2005

 File          : MultInt.c

 Hardware      : ADuC702x Rev I silicon

 Description   : Example program using two IRQs.
		 Timer1 causes an IRQ which complements P4.2.
		 XIRQ0 causes an IRQ which complements P4.2.
		
*********************************************************************/

#include "ioADuC7026.h"					// Include ADuC7024 Header File
											
//	Function Prototypes

void delay(int);
void DemoConfig(void);
long ADCconvert(void);
void delay (int length);


__irq __arm void irq_handler()			// example with two IRQs
{				
			
	if ((IRQSTA & XIRQ0_BIT) != 0) 			// external IRQ?
	{	
		GP4DAT ^= 0x00040000;			// Complement P4.2
		while(GP0DAT & 0x00010){}		// wait for XIRQ to be low again
	}			
	if ((IRQSTA & GP_TIMER_BIT) != 0)		// Timer1 IRQ?
	{
		T1CLRI = 0;				// Clear Timer IRQ
		GP4DAT ^= 0x00040000;			// Complement P4.2
		T1LD = 0x20000;				// Timer  reload
        } 						// required to clear ADC interrupt

}



// MAIN PROGRAM....

int main (void)  {

	DemoConfig();					// set up ADC, DAC, & reference

	GP0CON = 0x00;
	GP4DAT = 0x04000000;				// Configure P4.2 as output
	GP3DAT = 0xff000000;				// Configure port 3 as output
							// Timer 1 configuration
	T1LD = 0x8000;					// Counter Value
	T1CON = 0xC4;					// Enabled,Periodic,Binary and CLK/16

	IRQEN = XIRQ0_BIT + GP_TIMER_BIT;		// Enable XIRQ0 and Timer1 IRQ


	while(1)
	{
		GP3DAT ^= 0x00ff0000;			// Compliment P3
		ADCCON = 0x6A3;				// single conversion
		delay(0x2000);				// Delay Blinking of P3
	}

}

void delay (int length)
{
  while (length >=0)
    length--;
}

void DemoConfig(void) {				        // ADC, DAC and Reference configuration
	ADCCON = 0x620;				        // ADC on
        ADCCP = 0x00;					// conversion on ADC0
	DAC1CON = 0x13;					// AGND-AVDD range
	REFCON = 0x01;					// internal 2.5V reference

	return;
}



